@@ -47,6 +47,7 @@ from . import (DbReadBase, DbWriteBase, DbUndo, DBLOGNAME, DBUNDOFN,
                REPOSITORY_KEY, NOTE_KEY, TAG_KEY, TXNADD, TXNUPD, TXNDEL,
                KEY_TO_NAME_MAP, DBMODE_R, DBMODE_W)
 from .utils import write_lock_file, clear_lock_file
+from .exceptions import DbVersionError
 from ..errors import HandleError
 from ..utils.callback import Callback
 from ..updatecallback import UpdateCallback
@@ -534,7 +535,7 @@ class DbGeneric(DbWriteBase, DbReadBase, UpdateCallback, Callback):
         self.undo_history_callback = None
         self.modified = 0
         self.transaction = None
-        self.abort_possible = False
+        self.abort_possible = True
         self._bm_changes = 0
         self.has_changed = False
         self.surname_list = []
@@ -659,6 +660,12 @@ class DbGeneric(DbWriteBase, DbReadBase, UpdateCallback, Callback):
 
         self.db_is_open = True
 
+        # Check on db version to see if too new
+        dbversion = int(self._get_metadata('version', default='0'))
+        if dbversion > self.VERSION[0]:
+            self.close()
+            raise DbVersionError(dbversion, 18, self.VERSION[0])
+
     def _close(self):
         """
         Close database backend.
@@ -757,7 +764,7 @@ class DbGeneric(DbWriteBase, DbReadBase, UpdateCallback, Callback):
         if self._directory:
             filepath = os.path.join(self._directory, "name.txt")
             try:
-                with open(filepath, "r") as name_file:
+                with open(filepath, "r", encoding='utf8') as name_file:
                     name = name_file.readline().strip()
             except (OSError, IOError) as msg:
                 LOG.error(str(msg))
